==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/pl.py <==
info = {
    "name": "pl",
    "date_order": "DMY",
    "january": [
        "styczeń",
        "sty",
        "stycznia",
        "Styczeń",
        "Styczen",
        "Stycznia",
        "Styczniu",
        "Sty"
    ],
    "february": [
        "luty",
        "lut",
        "lutego",
        "Luty",
        "Lutego",
        "Lutym",
        "Lut"
    ],
    "march": [
        "marzec",
        "mar",
        "marca",
        "Marzec",
        "Marca",
        "Marcu",
        "Mar"
    ],
    "april": [
        "kwiecień",
        "kwi",
        "kwietnia",
        "Kwiecień",
        "Kwiecien",
        "Kwietnia",
        "Kwietniu",
        "Kwi",
        "Kwie"
    ],
    "may": [
        "maj",
        "maja",
        "Maj",
        "Maja",
        "Maju"
    ],
    "june": [
        "czerwiec",
        "cze",
        "czerwca",
        "Czerwiec",
        "Czerwca",
        "Czerwcu",
        "Cze"
    ],
    "july": [
        "lipiec",
        "lip",
        "lipca",
        "Lipiec",
        "Lipca",
        "Lipcu",
        "Lip"
    ],
    "august": [
        "sierpień",
        "sie",
        "sierpnia",
        "Sierpień",
        "Sierpien",
        "Sierpnia",
        "Sierpniu",
        "Sie"
    ],
    "september": [
        "wrzesień",
        "wrz",
        "września",
        "Wrzesień",
        "Wrzesien",
        "Września",
        "Wrzesnia",
        "Wrześniu",
        "Wrzesniu",
        "Wrz"
    ],
    "october": [
        "październik",
        "paź",
        "października",
        "Październik",
        "Pazdziernik",
        "Października",
        "Pazdziernika",
        "Październiku",
        "Pazdzierniku",
        "Paź",
        "Paz"
    ],
    "november": [
        "listopad",
        "lis",
        "listopada",
        "Listopad",
        "Listopada",
        "Listopadzie",
        "Lis"
    ],
    "december": [
        "grudzień",
        "gru",
        "grudnia",
        "Grudzień",
        "Grudzien",
        "Grudnia",
        "Grudniu",
        "Gru"
    ],
    "monday": [
        "poniedziałek",
        "pon",
        "Poniedziałek",
        "Poniedzialek",
        "Pon",
        "Pn"
    ],
    "tuesday": [
        "wtorek",
        "wt",
        "Wtorek",
        "Wt",
        "Wto"
    ],
    "wednesday": [
        "środa",
        "śr",
        "Środa",
        "Sroda",
        "Środę",
        "Srode",
        "Śro",
        "Sro",
        "Śr",
        "Sr"
    ],
    "thursday": [
        "czwartek",
        "czw",
        "Czwartek",
        "Czw",
        "Cz"
    ],
    "friday": [
        "piątek",
        "pt",
        "Piątek",
        "Piatek",
        "Pią",
        "Pia",
        "Pi",
        "Pt"
    ],
    "saturday": [
        "sobota",
        "sob",
        "Sobota",
        "Sobotę",
        "Sobote",
        "Sob",
        "So",
        "Sb"
    ],
    "sunday": [
        "niedziela",
        "niedz",
        "Niedziela",
        "Niedzielę",
        "Niedziele",
        "Nie",
        "Nd"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "rok",
        "r",
        "lata",
        "lat"
    ],
    "month": [
        "miesiąc",
        "mies",
        "mc",
        "miesiac",
        "miesięcy",
        "miesiąca",
        "miesiące",
        "miesiace"
    ],
    "week": [
        "tydzień",
        "tydz",
        "tydzien",
        "tygodni",
        "tygodnie"
    ],
    "day": [
        "dzień",
        "dzien",
        "dnia",
        "dniu",
        "dni"
    ],
    "hour": [
        "godzina",
        "godz",
        "g",
        "godzinę",
        "godzine",
        "godzin",
        "godziny"
    ],
    "minute": [
        "minuta",
        "min",
        "minuty",
        "minut",
        "minute",
        "minutę"
    ],
    "second": [
        "sekunda",
        "sek",
        "s",
        "sekundę",
        "sekunde",
        "sekundy",
        "sekund"
    ],
    "relative-type": {
        "1 year ago": [
            "w zeszłym roku"
        ],
        "0 year ago": [
            "w tym roku"
        ],
        "in 1 year": [
            "w przyszłym roku"
        ],
        "1 month ago": [
            "w zeszłym miesiącu"
        ],
        "0 month ago": [
            "w tym miesiącu"
        ],
        "in 1 month": [
            "w przyszłym miesiącu"
        ],
        "1 week ago": [
            "w zeszłym tygodniu"
        ],
        "0 week ago": [
            "w tym tygodniu"
        ],
        "in 1 week": [
            "w przyszłym tygodniu"
        ],
        "1 day ago": [
            "wczoraj"
        ],
        "0 day ago": [
            "dzisiaj"
        ],
        "in 1 day": [
            "jutro"
        ],
        "0 hour ago": [
            "ta godzina"
        ],
        "0 minute ago": [
            "ta minuta"
        ],
        "0 second ago": [
            "teraz"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) rok",
            "za (\\d+) roku"
        ],
        "\\1 year ago": [
            "(\\d+) rok temu",
            "(\\d+) roku temu"
        ],
        "in \\1 month": [
            "za (\\d+) miesiąc",
            "za (\\d+) miesiąca",
            "za (\\d+) mies"
        ],
        "\\1 month ago": [
            "(\\d+) miesiąc temu",
            "(\\d+) miesiąca temu",
            "(\\d+) mies temu",
            "–(\\d+) mies"
        ],
        "in \\1 week": [
            "za (\\d+) tydzień",
            "za (\\d+) tygodnia",
            "za (\\d+) tydz",
            "za (\\d+) tyg"
        ],
        "\\1 week ago": [
            "(\\d+) tydzień temu",
            "(\\d+) tygodnia temu",
            "(\\d+) tydz temu",
            "(\\d+) tyg temu"
        ],
        "in \\1 day": [
            "za (\\d+) dzień",
            "za (\\d+) dnia"
        ],
        "\\1 day ago": [
            "(\\d+) dzień temu",
            "(\\d+) dnia temu"
        ],
        "in \\1 hour": [
            "za (\\d+) godzinę",
            "za (\\d+) godziny",
            "za (\\d+) godz",
            "za (\\d+) g"
        ],
        "\\1 hour ago": [
            "(\\d+) godzinę temu",
            "(\\d+) godziny temu",
            "(\\d+) godz temu",
            "(\\d+) g temu"
        ],
        "in \\1 minute": [
            "za (\\d+) minutę",
            "za (\\d+) minuty",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minutę temu",
            "(\\d+) minuty temu",
            "(\\d+) min temu"
        ],
        "in \\1 second": [
            "za (\\d+) sekundę",
            "za (\\d+) sekundy",
            "za (\\d+) sek",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "(\\d+) sekundę temu",
            "(\\d+) sekundy temu",
            "(\\d+) sek temu",
            "(\\d+) s temu"
        ]
    },
    "locale_specific": {},
    "sentence_splitter_group": 1,
    "skip": [
        "r.",
        "roku",
        "w",
        "o",
        "i",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "ago": [
        "temu"
    ],
    "in": [
        "za"
    ],
    "simplifications": [
        {
            "dziś": "0 dnia"
        },
        {
            "dzisiaj": "0 dnia"
        },
        {
            "onegdaj": "2 dnia"
        },
        {
            "przedwczoraj": "2 dnia temu"
        },
        {
            "jutro": "za 1 dnia"
        },
        {
            "pojutrze": "za 2 dnia"
        }
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/pl.py <==
info = {
    "name": "pl",
    "date_order": "DMY",
    "january": [
        "sty",
        "styczeń",
        "stycznia",
        "Styczeń",
        "Styczen",
        "Stycznia",
        "Styczniu",
        "Sty"
    ],
    "february": [
        "lut",
        "lutego",
        "luty",
        "Luty",
        "Lutego",
        "Lutym",
        "Lut"
    ],
    "march": [
        "mar",
        "marca",
        "marzec",
        "Marzec",
        "Marca",
        "Marcu",
        "Mar"
    ],
    "april": [
        "kwi",
        "kwiecień",
        "kwietnia",
        "Kwiecień",
        "Kwiecien",
        "Kwietnia",
        "Kwietniu",
        "Kwi",
        "Kwie"
    ],
    "may": [
        "maj",
        "maja",
        "Maj",
        "Maja",
        "Maju"
    ],
    "june": [
        "cze",
        "czerwca",
        "czerwiec",
        "Czerwiec",
        "Czerwca",
        "Czerwcu",
        "Cze"
    ],
    "july": [
        "lip",
        "lipca",
        "lipiec",
        "Lipiec",
        "Lipca",
        "Lipcu",
        "Lip"
    ],
    "august": [
        "sie",
        "sierpień",
        "sierpnia",
        "Sierpień",
        "Sierpien",
        "Sierpnia",
        "Sierpniu",
        "Sie"
    ],
    "september": [
        "wrz",
        "wrzesień",
        "września",
        "Wrzesień",
        "Wrzesien",
        "Września",
        "Wrzesnia",
        "Wrześniu",
        "Wrzesniu",
        "Wrz"
    ],
    "october": [
        "paź",
        "październik",
        "października",
        "Październik",
        "Pazdziernik",
        "Października",
        "Pazdziernika",
        "Październiku",
        "Pazdzierniku",
        "Paź",
        "Paz"
    ],
    "november": [
        "lis",
        "listopad",
        "listopada",
        "Listopad",
        "Listopada",
        "Listopadzie",
        "Lis"
    ],
    "december": [
        "gru",
        "grudnia",
        "grudzień",
        "Grudzień",
        "Grudzien",
        "Grudnia",
        "Grudniu",
        "Gru"
    ],
    "monday": [
        "pon",
        "poniedziałek",
        "Poniedziałek",
        "Poniedzialek",
        "Pon",
        "Pn"
    ],
    "tuesday": [
        "wt",
        "wtorek",
        "Wtorek",
        "Wt",
        "Wto"
    ],
    "wednesday": [
        "śr",
        "środa",
        "Środa",
        "Sroda",
        "Środę",
        "Srode",
        "Śro",
        "Sro",
        "Śr",
        "Sr"
    ],
    "thursday": [
        "czw",
        "czwartek",
        "Czwartek",
        "Czw",
        "Cz"
    ],
    "friday": [
        "piątek",
        "pt",
        "Piątek",
        "Piatek",
        "Pią",
        "Pia",
        "Pi",
        "Pt"
    ],
    "saturday": [
        "sob",
        "sobota",
        "Sobota",
        "Sobotę",
        "Sobote",
        "Sob",
        "So",
        "Sb"
    ],
    "sunday": [
        "niedz",
        "niedziela",
        "Niedziela",
        "Niedzielę",
        "Niedziele",
        "Nie",
        "Nd"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "r",
        "rok",
        "lata",
        "lat"
    ],
    "month": [
        "mc",
        "mies",
        "miesiąc",
        "miesiac",
        "miesięcy",
        "miesiąca",
        "miesiące",
        "miesiace"
    ],
    "week": [
        "tydz",
        "tydzień",
        "tydzien",
        "tygodni",
        "tygodnie"
    ],
    "day": [
        "dzień",
        "dzien",
        "dnia",
        "dniu",
        "dni"
    ],
    "hour": [
        "g",
        "godz",
        "godzina",
        "godzinę",
        "godzine",
        "godzin",
        "godziny"
    ],
    "minute": [
        "min",
        "minuta",
        "minuty",
        "minut",
        "minute",
        "minutę"
    ],
    "second": [
        "s",
        "sek",
        "sekunda",
        "sekundę",
        "sekunde",
        "sekundy",
        "sekund"
    ],
    "relative-type": {
        "0 day ago": [
            "dzisiaj"
        ],
        "0 hour ago": [
            "ta godzina"
        ],
        "0 minute ago": [
            "ta minuta"
        ],
        "0 month ago": [
            "w tym miesiącu"
        ],
        "0 second ago": [
            "teraz"
        ],
        "0 week ago": [
            "w tym tygodniu"
        ],
        "0 year ago": [
            "w tym roku"
        ],
        "1 day ago": [
            "wczoraj"
        ],
        "1 month ago": [
            "w zeszłym miesiącu"
        ],
        "1 week ago": [
            "w zeszłym tygodniu"
        ],
        "1 year ago": [
            "w zeszłym roku"
        ],
        "in 1 day": [
            "jutro"
        ],
        "in 1 month": [
            "w przyszłym miesiącu"
        ],
        "in 1 week": [
            "w przyszłym tygodniu"
        ],
        "in 1 year": [
            "w przyszłym roku"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) dnia temu",
            "(\\d+) dzień temu"
        ],
        "\\1 hour ago": [
            "(\\d+) g temu",
            "(\\d+) godz temu",
            "(\\d+) godziny temu",
            "(\\d+) godzinę temu"
        ],
        "\\1 minute ago": [
            "(\\d+) min temu",
            "(\\d+) minuty temu",
            "(\\d+) minutę temu"
        ],
        "\\1 month ago": [
            "(\\d+) mies temu",
            "(\\d+) miesiąc temu",
            "(\\d+) miesiąca temu",
            "–(\\d+) mies"
        ],
        "\\1 second ago": [
            "(\\d+) s temu",
            "(\\d+) sek temu",
            "(\\d+) sekundy temu",
            "(\\d+) sekundę temu"
        ],
        "\\1 week ago": [
            "(\\d+) tydz temu",
            "(\\d+) tydzień temu",
            "(\\d+) tyg temu",
            "(\\d+) tygodnia temu"
        ],
        "\\1 year ago": [
            "(\\d+) rok temu",
            "(\\d+) roku temu"
        ],
        "in \\1 day": [
            "za (\\d+) dnia",
            "za (\\d+) dzień"
        ],
        "in \\1 hour": [
            "za (\\d+) g",
            "za (\\d+) godz",
            "za (\\d+) godziny",
            "za (\\d+) godzinę"
        ],
        "in \\1 minute": [
            "za (\\d+) min",
            "za (\\d+) minuty",
            "za (\\d+) minutę"
        ],
        "in \\1 month": [
            "za (\\d+) mies",
            "za (\\d+) miesiąc",
            "za (\\d+) miesiąca"
        ],
        "in \\1 second": [
            "za (\\d+) s",
            "za (\\d+) sek",
            "za (\\d+) sekundy",
            "za (\\d+) sekundę"
        ],
        "in \\1 week": [
            "za (\\d+) tydz",
            "za (\\d+) tydzień",
            "za (\\d+) tyg",
            "za (\\d+) tygodnia"
        ],
        "in \\1 year": [
            "za (\\d+) rok",
            "za (\\d+) roku"
        ]
    },
    "locale_specific": {},
    "sentence_splitter_group": 1,
    "skip": [
        "i",
        "o",
        "r.",
        "roku",
        "w",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "ago": [
        "temu"
    ],
    "in": [
        "za"
    ],
    "simplifications": [
        {
            "dziś": "0 dnia"
        },
        {
            "dzisiaj": "0 dnia"
        },
        {
            "onegdaj": "2 dnia"
        },
        {
            "przedwczoraj": "2 dnia temu"
        },
        {
            "jutro": "za 1 dnia"
        },
        {
            "pojutrze": "za 2 dnia"
        }
    ]
}
